Author: Aloha Editor Team

Aloha Editor Demo
Edit Save

Loading Aloha Editor

## Feedback

Send us your feedback. This shows how to use Aloha Editor with texarea.

How do you like Aloha Editor?
Name
Twitter ID
@
Like Aloha Editor?
List of Options

- I like to use Aloha Editor
- I like to support Aloha Editor
- I like an invitation for the next hackathon.

Note: Labels surround all the options for much larger click areas and a more usable form.
Message
Write about your experience with Aloha Editor.